# mypy-boto3-s3control<a id="mypy-boto3-s3control"></a>

[![PyPI - mypy-boto3-s3control](https://img.shields.io/pypi/v/mypy-boto3-s3control.svg?color=blue)](https://pypi.org/project/mypy-boto3-s3control)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-s3control.svg?color=blue)](https://pypi.org/project/mypy-boto3-s3control)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-s3control?color=blue)](https://pypistats.org/packages/mypy-boto3-s3control)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.S3Control 1.17.78](https://boto3.amazonaws.com/v1/documentation/api/1.17.78/reference/services/s3control.html#S3Control)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.13.1](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-s3control docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3control/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-s3control](#mypy-boto3-s3control)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

## How to install<a id="how-to-install"></a>

Install `boto3-stubs` for `S3Control` service.

```bash
python -m pip install boto3-stubs[s3control]
```

## Usage<a id="usage"></a>

### VSCode<a id="vscode"></a>

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[s3control]` in your environment:
  `python -m pip install 'boto3-stubs[s3control]'`

Both type checking and auto-complete should work for `S3Control` service. No
explicit type annotations required, write your `boto3` code as usual.

### PyCharm<a id="pycharm"></a>

- Install `boto-stubs[s3control]` in your environment:
  `python -m pip install 'boto3-stubs[s3control]'`

Both type checking and auto-complete should work for `S3Control` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

### Other IDEs<a id="other-ides"></a>

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

### mypy<a id="mypy"></a>

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[s3control]` in your environment:
  `python -m pip install 'boto3-stubs[s3control]'`
- Run `mypy` as usual

Type checking should work for `S3Control` service. No explicit type annotations
required, write your `boto3` code as usual.

### pyright<a id="pyright"></a>

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[s3control]` in your environment:
  `python -m pip install 'boto3-stubs[s3control]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `S3Control` service. No explicit type annotations
required, write your `boto3` code as usual.

## Explicit type annotations<a id="explicit-type-annotations"></a>

### Client annotations<a id="client-annotations"></a>

`S3ControlClient` provides annotations for `boto3.client("s3control")`.

```python
import boto3

from mypy_boto3_s3control import S3ControlClient

client: S3ControlClient = boto3.client("s3control")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: S3ControlClient = session.client("s3control")
```

### Paginators annotations<a id="paginators-annotations"></a>

`mypy_boto3_s3control.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_s3control import S3ControlClient
from mypy_boto3_s3control.paginator import (
    ListAccessPointsForObjectLambdaPaginator,
)

client: S3ControlClient = boto3.client("s3control")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_access_points_for_object_lambda_paginator: ListAccessPointsForObjectLambdaPaginator = client.get_paginator("list_access_points_for_object_lambda")
```

### Literals<a id="literals"></a>

`mypy_boto3_s3control.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_s3control.literals import (
    BucketCannedACLType,
    BucketLocationConstraintType,
    ExpirationStatusType,
    FormatType,
    JobManifestFieldNameType,
    JobManifestFormatType,
    JobReportFormatType,
    JobReportScopeType,
    JobStatusType,
    ListAccessPointsForObjectLambdaPaginatorName,
    NetworkOriginType,
    ObjectLambdaAllowedFeatureType,
    ObjectLambdaTransformationConfigurationActionType,
    OperationNameType,
    OutputSchemaVersionType,
    RequestedJobStatusType,
    S3CannedAccessControlListType,
    S3GlacierJobTierType,
    S3GranteeTypeIdentifierType,
    S3MetadataDirectiveType,
    S3ObjectLockLegalHoldStatusType,
    S3ObjectLockModeType,
    S3ObjectLockRetentionModeType,
    S3PermissionType,
    S3SSEAlgorithmType,
    S3StorageClassType,
    TransitionStorageClassType,
)

def check_value(value: BucketCannedACLType) -> bool:
    ...
```

### Typed dictionaries<a id="typed-dictionaries"></a>

`mypy_boto3_s3control.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_s3control.type_defs import (
    AbortIncompleteMultipartUploadTypeDef,
    AccessPointTypeDef,
    AccountLevelTypeDef,
    ActivityMetricsTypeDef,
    AwsLambdaTransformationTypeDef,
    BucketLevelTypeDef,
    CreateAccessPointForObjectLambdaResultTypeDef,
    CreateAccessPointResultTypeDef,
    CreateBucketConfigurationTypeDef,
    CreateBucketResultTypeDef,
    CreateJobResultTypeDef,
    DescribeJobResultTypeDef,
    ExcludeTypeDef,
    GetAccessPointConfigurationForObjectLambdaResultTypeDef,
    GetAccessPointForObjectLambdaResultTypeDef,
    GetAccessPointPolicyForObjectLambdaResultTypeDef,
    GetAccessPointPolicyResultTypeDef,
    GetAccessPointPolicyStatusForObjectLambdaResultTypeDef,
    GetAccessPointPolicyStatusResultTypeDef,
    GetAccessPointResultTypeDef,
    GetBucketLifecycleConfigurationResultTypeDef,
    GetBucketPolicyResultTypeDef,
    GetBucketResultTypeDef,
    GetBucketTaggingResultTypeDef,
    GetJobTaggingResultTypeDef,
    GetPublicAccessBlockOutputTypeDef,
    GetStorageLensConfigurationResultTypeDef,
    GetStorageLensConfigurationTaggingResultTypeDef,
    IncludeTypeDef,
    JobDescriptorTypeDef,
    JobFailureTypeDef,
    JobListDescriptorTypeDef,
    JobManifestLocationTypeDef,
    JobManifestSpecTypeDef,
    JobManifestTypeDef,
    JobOperationTypeDef,
    JobProgressSummaryTypeDef,
    JobReportTypeDef,
    LambdaInvokeOperationTypeDef,
    LifecycleConfigurationTypeDef,
    LifecycleExpirationTypeDef,
    LifecycleRuleAndOperatorTypeDef,
    LifecycleRuleFilterTypeDef,
    LifecycleRuleTypeDef,
    ListAccessPointsForObjectLambdaResultTypeDef,
    ListAccessPointsResultTypeDef,
    ListJobsResultTypeDef,
    ListRegionalBucketsResultTypeDef,
    ListStorageLensConfigurationEntryTypeDef,
    ListStorageLensConfigurationsResultTypeDef,
    NoncurrentVersionExpirationTypeDef,
    NoncurrentVersionTransitionTypeDef,
    ObjectLambdaAccessPointTypeDef,
    ObjectLambdaConfigurationTypeDef,
    ObjectLambdaContentTransformationTypeDef,
    ObjectLambdaTransformationConfigurationTypeDef,
    PaginatorConfigTypeDef,
    PolicyStatusTypeDef,
    PrefixLevelStorageMetricsTypeDef,
    PrefixLevelTypeDef,
    PublicAccessBlockConfigurationTypeDef,
    RegionalBucketTypeDef,
    ResponseMetadataTypeDef,
    S3AccessControlListTypeDef,
    S3AccessControlPolicyTypeDef,
    S3BucketDestinationTypeDef,
    S3CopyObjectOperationTypeDef,
    S3GrantTypeDef,
    S3GranteeTypeDef,
    S3InitiateRestoreObjectOperationTypeDef,
    S3ObjectLockLegalHoldTypeDef,
    S3ObjectMetadataTypeDef,
    S3ObjectOwnerTypeDef,
    S3RetentionTypeDef,
    S3SetObjectAclOperationTypeDef,
    S3SetObjectLegalHoldOperationTypeDef,
    S3SetObjectRetentionOperationTypeDef,
    S3SetObjectTaggingOperationTypeDef,
    S3TagTypeDef,
    SSEKMSTypeDef,
    SelectionCriteriaTypeDef,
    StorageLensAwsOrgTypeDef,
    StorageLensConfigurationTypeDef,
    StorageLensDataExportEncryptionTypeDef,
    StorageLensDataExportTypeDef,
    StorageLensTagTypeDef,
    TaggingTypeDef,
    TransitionTypeDef,
    UpdateJobPriorityResultTypeDef,
    UpdateJobStatusResultTypeDef,
    VpcConfigurationTypeDef,
)

def get_structure() -> AbortIncompleteMultipartUploadTypeDef:
    return {
      ...
    }
```

## Versioning<a id="versioning"></a>

`mypy-boto3-s3control` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Documentation<a id="documentation"></a>

All type annotations can be found in
[mypy-boto3-s3control docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3control/)

## Support and contributing<a id="support-and-contributing"></a>

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
